# 📈 Reporter

Reporter generates human friendly reports and graphs of your Broadworks instance. This can show Broadworks entity call volume over a period of time or a call flow chart showing how calls flow through your system when calling a specific number.&#x20;

{% hint style="info" %}
To make use of the features that generate graphs and charts such as Call Flow you will need to install Graphviz [here](https://graphviz.org/download/).
{% endhint %}
